//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[IRegularHandPattern](index.md)/[mentsu](mentsu.md)

# mentsu

[common]\
open val [mentsu](mentsu.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Mentsu](../../mahjongutils.models/-mentsu/index.md)&gt;

面子（包括门前与副露）
